@@ -1,4 +1,4 @@
-;; Copyright (C) 2015-2017, 2019 Free Software Foundation, Inc
+;; Copyright (C) 2015-2017, 2019, 2026 Free Software Foundation, Inc
 
 ;; Author: Rocky Bernstein <rocky@gnu.org>
 
@@ -343,8 +343,8 @@ EVENT should be a mouse click on the left fringe or margin."
 (defun realgud:cmd-finish(&optional arg)
     "Run until the completion of the current stack frame.
 
-This command is often referred to as 'step out' as opposed to
-'step over' or 'step into'."
+This command is often referred to as \"step out\" as opposed to
+\"step over\" or \"step into\"."
     (interactive "p")
     (realgud:cmd-run-command arg "finish")
 )
@@ -408,7 +408,7 @@ what is getting stepped."
 (defun realgud:cmd-next-no-arg()
   "Step one source line at current call level.
 
-The definition of 'next' is debugger specific so, see the
+The definition of \"next\" is debugger specific so, see the
 debugger documentation for a more complete definition of what is
 getting stepped."
     (interactive)
@@ -462,7 +462,7 @@ what is getting stepped."
 
 (defun realgud:cmd-terminate ()
   "Gently terminate source and command buffers without possibly
-issuing a command to the underlying debuger.  Use this if the
+issuing a command to the underlying debugger.  Use this if the
 underlying debugger has died or you want to get out of all
 shortkey modes in the source window and possibly restart
 debugging after editing source."
